@@ -1,21 +1,19 @@
 source("utils.R")
 
 test_that("add text into placeholder", {
-  doc <- read_pptx() %>%
-    add_slide("Title and Content", "Office Theme") %>%
-    ph_with("", location = ph_location(left = 1, top = 1, width = 3, height = 2))
+  doc <- read_pptx()
+  doc <- add_slide(doc, "Title and Content", "Office Theme")
+  doc <- ph_with(doc, "", location = ph_location(left = 1, top = 1, width = 3, height = 2))
   sm <- slide_summary(doc)
 
   expect_equal(nrow(sm), 1)
 
   small_red <- fp_text(color = "red", font.size = 14)
-  doc <- doc %>%
-    ph_add_text(str = "chunk 1", style = small_red, type = "body" )
+  doc <- ph_add_text(doc, str = "chunk 1", style = small_red, type = "body" )
   sm <- slide_summary(doc)
   expect_equal(sm[1, ]$text, "chunk 1")
 
-  doc <- doc %>%
-    ph_add_text(str = "this is ", style = small_red, pos = "before", type = "body" )
+  doc <- ph_add_text(doc, str = "this is ", style = small_red, pos = "before", type = "body" )
   sm <- slide_summary(doc)
   expect_equal(sm[1, ]$text, "this is chunk 1")
 
@@ -34,9 +32,9 @@ test_that("add text into placeholder", {
 test_that("add img into placeholder", {
   skip_on_os("windows")
   img.file <- file.path( R.home("doc"), "html", "logo.jpg" )
-  doc <- read_pptx() %>%
-    add_slide("Title and Content", "Office Theme") %>%
-    ph_with(value = external_img(img.file), location = ph_location(left = 1, top = 1,
+  doc <- read_pptx()
+  doc <- add_slide(doc, "Title and Content", "Office Theme")
+  doc <- ph_with(doc, value = external_img(img.file), location = ph_location(left = 1, top = 1,
                 height = 1.06, width = 1.39) )
   sm <- slide_summary(doc)
 
